<?php
namespace Teknisa\Model\Gestaopessoas\Repositories;

use HCM\Util\Repositories;

class EsoNaoperiodico extends \Doctrine\ORM\EntityRepository {
    
    public function getEnviosEvento($nrorg, $nmevento, $nrestruturam, $nrtpambiente, $nrvinculom, $idativo = 'S', $nrchave = null, $nrtabela = null, $idoperacao = array(), $nrenvioexcl=null) {
        try{
            $esoNaoperiodico = Repositories::ESO_NAOPERIODICO;
            $esoEvento = Repositories::ESO_EVENTO;
            
            $db = \Setforms2\Shared\Registry::getEntityManagerConnection();
            $params = array(
                'nrorg' => $nrorg,
                'nmevento' => $nmevento,
                'nrestruturam' => $nrestruturam,
                'nrtpambiente' => $nrtpambiente,
                'nrvinculom' => $nrvinculom,
                'idativo' => $idativo,
                'nrchave' => $nrchave,
                'nrtabela' => $nrtabela,
                'nrenvioexcl' => $nrenvioexcl,
            );
            $sql = "SELECT envio
                      FROM $esoNaoperiodico envio
                     WHERE envio.nrorg = :nrorg
                       AND envio.nmevento = :nmevento
                       AND (envio.nrestruturam = :nrestruturam OR (envio.nrestruturam <> :nrestruturam AND envio.nmevento IN ('S-2205','S-2206','S-2306'))) 
                       AND envio.nrtpambiente = :nrtpambiente
                       AND envio.nrvinculom = :nrvinculom
                       AND envio.idativo = :idativo
                       AND (envio.nrchave = :nrchave OR :nrchave IS NULL)
                       AND (envio.nrtabela = :nrtabela OR :nrtabela IS NULL)
                       AND ((:nrenvioexcl = 'S' AND envio.nrenvioexcl IS NOT NULL) OR (:nrenvioexcl = 'N' AND envio.nrenvioexcl IS NULL) OR :nrenvioexcl IS NULL)";
            
            if (!empty($idoperacao)) {
                $sql .= " AND (envio.idoperacao IN ('".implode("','",$idoperacao)."'))";
            }
           
            return $this->getEntityManager()->createQuery($sql)->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    
    public function ativaEvento($nrenvio, $nrorg, $nrestruturam, $cdOper, $dataUltAtul){
        try{
            $esoNaoperiodico = Repositories::ESO_NAOPERIODICO;
            $sql = 
            "UPDATE $esoNaoperiodico esoNPer
               SET esoNPer.idativo = 'S',
                   esoNPer.nrorgultatu = :p_nrorg,
                   esoNPer.dtultatu = :p_dtultatu,
                   esoNPer.cdoperultatu = :p_cdoperador
             WHERE esoNPer.nrorg = :p_nrorg
               AND esoNPer.nrestruturam = :p_nrestruturam
               AND esoNPer.idativo = 'N'
               AND esoNPer.nrenvio = :p_nrenvio";
            $params = array(
                "p_nrorg" => $nrorg,
                "p_nrestruturam" => $nrestruturam,
                "p_nrenvio" => $nrenvio,
                "p_cdoperador" => $cdOper,
                "p_dtultatu" => $dataUltAtul
            );

        return $this->getEntityManager()->createQuery($sql)->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getEnvioAdmissaoVinculo($nrorg, $nrtpambiente, $cdcnpjempregador, $nrvinculom, $dtmescompetenc) {
        try{
            $esoNaoperiodico = Repositories::ESO_NAOPERIODICO;
            $estruturah = Repositories::ESTRUTURAH;
            
            $db = \Setforms2\Shared\Registry::getEntityManagerConnection();
            $params = array(
                'nrorg' => $nrorg,
                'nrtpambiente' => $nrtpambiente,
                'cdcnpjempregador' => $cdcnpjempregador,
                'nrvinculom' => $nrvinculom,
                'dtmescompetenc' => $dtmescompetenc,
            );
            $sql = "SELECT envio
                      FROM $esoNaoperiodico envio
                      JOIN $estruturah evh WITH evh.nrorg = envio.nrorg
                                            AND evh.nrestruturam = envio.nrestruturam
                                            AND SUBSTRING(evh.cdcnpjestrut,1,8) = SUBSTRING(:cdcnpjempregador,1,8)
                                            AND evh.dtmescompetenc = (SELECT MAX(h1.dtmescompetenc) FROM $estruturah h1
                                                                       WHERE h1.nrorg = evh.nrorg
                                                                         AND h1.nrestruturam = evh.nrestruturam
                                                                         AND h1.dtmescompetenc <= :dtmescompetenc)
                     WHERE envio.nrorg = :nrorg
                       AND envio.nrtpambiente = :nrtpambiente
                       AND envio.nrvinculom = :nrvinculom
                       AND envio.nmevento IN ('S-2200','S-2300')
                       AND envio.idativo = 'S'
                       AND envio.nrenvioexcl IS NULL
                     ORDER BY envio.dtmescompetenc DESC";
           
            return $this->getEntityManager()->createQuery($sql)->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getEnvioRescisaoVinculo($nrorg, $nrtpambiente, $cdcnpjempregador, $nrvinculom, $dtmescompetenc, $idstatus = array()) {
        try{
            $esoNaoperiodico = Repositories::ESO_NAOPERIODICO;
            $estruturah = Repositories::ESTRUTURAH;
            
            $db = \Setforms2\Shared\Registry::getEntityManagerConnection();
            $params = array(
                'nrorg' => $nrorg,
                'nrtpambiente' => $nrtpambiente,
                'cdcnpjempregador' => $cdcnpjempregador,
                'nrvinculom' => $nrvinculom,
                'dtmescompetenc' => $dtmescompetenc,
            );
            $sql = "SELECT envio
                      FROM $esoNaoperiodico envio
                      JOIN $estruturah evh WITH evh.nrorg = envio.nrorg
                                            AND evh.nrestruturam = envio.nrestruturam
                                            AND SUBSTRING(evh.cdcnpjestrut,1,8) = SUBSTRING(:cdcnpjempregador,1,8)
                                            AND evh.dtmescompetenc = (SELECT MAX(h1.dtmescompetenc) FROM $estruturah h1
                                                                       WHERE h1.nrorg = evh.nrorg
                                                                         AND h1.nrestruturam = evh.nrestruturam
                                                                         AND h1.dtmescompetenc <= :dtmescompetenc)
                     WHERE envio.nrorg = :nrorg
                       AND envio.nrtpambiente = :nrtpambiente
                       AND envio.nrvinculom = :nrvinculom
                       AND envio.nmevento IN ('S-2299','S-2399')
                       AND envio.idativo = 'S'
                       AND envio.nrenvioexcl IS NULL";
            
            if (!empty($idstatus)) {
                $sql .= " AND (envio.idstatus IN ('".implode("','",$idstatus)."'))";
            }
            
            $sql .= " ORDER BY envio.dtmescompetenc DESC";
           
            return $this->getEntityManager()->createQuery($sql)->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getEnviosEventoEstabelecimento($nrorg, $nrtpambiente, $nrestruturam, $nmevento, $nrestrutestab, $dtmescompetenc, $idativo = 'S', $idstatus = array(), $idoperacao = array(), $nrvinculom = null, $nrchave = null, $nrtabela = null, $nrenvioexcl=null) {
        try{
            $esoNaoperiodico = Repositories::ESO_NAOPERIODICO;
            $gpeVinculoh = Repositories::GPE_VINCULOH;
            
            $db = \Setforms2\Shared\Registry::getEntityManagerConnection();
            $params = array(
                'nrorg' => $nrorg,
                'nrtpambiente' => $nrtpambiente,
                'nrestruturam' => $nrestruturam,
                'nmevento' => $nmevento,
                'nrestrutestab' => $nrestrutestab,
                'dtmescompetenc' => $dtmescompetenc,
                'idativo' => $idativo,
                'nrvinculom' => $nrvinculom,
                'nrchave' => $nrchave,
                'nrtabela' => $nrtabela,
                'nrenvioexcl' => $nrenvioexcl,
            );
            $sql = "SELECT envio
                      FROM $esoNaoperiodico envio
                      JOIN $gpeVinculoh vinch WITH vinch.nrorg = envio.nrorg
                                               AND vinch.nrvinculom = envio.nrvinculom
                                               AND vinch.dtmescompetenc = (SELECT MAX(h1.dtmescompetenc) FROM $gpeVinculoh h1
                                                                            WHERE h1.nrorg = vinch.nrorg
                                                                              AND h1.nrvinculom = vinch.nrvinculom
                                                                              AND h1.dtmescompetenc <= :dtmescompetenc)
                     WHERE envio.nrorg = :nrorg
                       AND envio.nrtpambiente = :nrtpambiente
                       AND envio.nrestruturam = :nrestruturam
                       AND envio.nmevento = :nmevento
                       AND envio.idativo = :idativo
                       AND (envio.nrvinculom = :nrvinculom OR :nrvinculom IS NULL)
                       AND (envio.nrchave = :nrchave OR :nrchave IS NULL)
                       AND (envio.nrtabela = :nrtabela OR :nrtabela IS NULL)
                       AND ((:nrenvioexcl = 'S' AND envio.nrenvioexcl IS NOT NULL) OR (:nrenvioexcl = 'N' AND envio.nrenvioexcl IS NULL) OR :nrenvioexcl IS NULL)
                       AND vinch.nrestrutlegal = :nrestrutestab";
            
            if (!empty($idstatus)) {
                $sql .= " AND (envio.idstatus IN ('".implode("','",$idstatus)."'))";
            }
            
            if (!empty($idoperacao)) {
                $sql .= " AND (envio.idoperacao IN ('".implode("','",$idoperacao)."'))";
            }
            
            return $this->getEntityManager()->createQuery($sql)->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateEnvios($idStatus, $cdErro, $dsObservacao, $dsObservacao2=null, $dtRecepcao, $nrProtocolo, $allNrEnvio = array(), $nrOrg, $dtUltAtu, $cdOperUltAtu, $nrOrgUltAtu) {
        try{
            $esoNaoperiodico = Repositories::ESO_NAOPERIODICO;
            
            $params = array(
                'idstatus' => $idStatus,
                'cderro' => $cdErro,
                'dsobservacao' => $dsObservacao,
                'dsobservacao2' => $dsObservacao2,
                'dtresposta' => $dtRecepcao,
                'nrprotocolo' => $nrProtocolo,
                'nrorg' => $nrOrg,
                'dtultatu' => $dtUltAtu,
                'cdoperultatu' => $cdOperUltAtu,
                'nrorgultatu' => $nrOrgUltAtu
            );
            $sql = "UPDATE $esoNaoperiodico esonp
                      SET esonp.idstatus = :idstatus,
                      esonp.cderro = :cderro,
                      esonp.dsobservacao = :dsobservacao,
                      esonp.dsobservacao2 = :dsobservacao2,
                      esonp.dtresposta = :dtresposta,
                      esonp.nrprotocolo = :nrprotocolo,
                      esonp.dtultatu = :dtultatu,
                      esonp.cdoperultatu = :cdoperultatu,
                      esonp.nrorgultatu = :nrorgultatu
                     WHERE esonp.nrorg = :nrorg
                       AND (esonp.nrenvio IN ('".implode("','",$allNrEnvio)."'))";
            
            $this->getEntityManager()->createQuery($sql)->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
}